((Drupal) => {
  // LegalWeb Cloud Enhancements.
  Drupal.behaviors.legalwebCloudEnhancements = {
    attach(context, settings)  {
      this.overlay = context.querySelector('.sp-dsgvo-popup-overlay');
      if (!this.overlay) {
        return;
      }
      // Initialize.
      this.initValues();

      if (settings.legalwebCloudEnhancements.adjustButtonLabels) {
        this.adjustButtonLabels();
        // Initial selection check.
        this._checkSelection();
        // Add event listeners.
        [].forEach.call(this.checkboxes, checkbox => {
          checkbox.addEventListener('change', this._checkSelection.bind(this));
        });
        [].forEach.call(this.categories, category => {
          category.addEventListener('change', this._checkCategorySelection.bind(this));
        });
      }

      if (settings.legalwebCloudEnhancements.removeCloseButton) {
        this.removeCloseButton();
      }

      if (settings.legalwebCloudEnhancements.disableOutsideClick) {
        this.disableOutsideClickBehavior();
      }
    },
    initValues() {
      this.popup = this.overlay.querySelector('.sp-dsgvo-privacy-popup');
      this.buttons = {};
      this.buttons.all = this.popup.querySelectorAll('.sp-dsgvo-popup-button');
      this.buttons.acceptSelection = this.popup.querySelectorAll('.sp-dsgvo-privacy-btn-accept-selection');
      this.buttons.acceptNothing = this.popup.querySelectorAll('.sp-dsgvo-privacy-btn-accept-nothing');
      this.checkboxes = this.popup.querySelectorAll('.switch-input:not(.switch-input-category)');
      this.categories = this.popup.querySelectorAll('.switch-input-category');
    },
    disableOutsideClickBehavior() {
      window.addEventListener('click', this._clickOutHandler, {capture: true});
      window.addEventListener('touchstart', this._clickOutHandler, {capture: true});
    },
    removeCloseButton() {
      const closeBtn = this.popup.querySelector('.sp-dsgvo-popup-close');
      if (null !== closeBtn) {
        closeBtn.remove();
      }
    },
    adjustButtonLabels() {
      // Fix the layout.
      [].forEach.call(this.buttons.all, btn => {
        btn.style.minWidth = '40%';
        btn.style.textAlign = 'center';
      });
      // Save button labels.
      this.labels = {
        selected: this.buttons.acceptSelection[0].textContent,
        nothing: this.buttons.acceptNothing[0].textContent,
      };
      // Remove "Accept Nothing" button.
      [].forEach.call(this.buttons.acceptNothing, btn => {
        btn.remove();
      });
    },

    isNoneChecked() {
      return this.popup
        .querySelectorAll('input.switch-input:not(.switch-input-category):checked')
        .length === 0;
    },

    _clickOutHandler(e) {
      if (e.target.classList.contains('sp-dsgvo-popup-overlay')) {
        e.stopPropagation();
        return false;
      }
    },

    _checkSelection() {
      if (this.isNoneChecked()) {
        // None checked.
        [].forEach.call(this.buttons.acceptSelection, btn => {
          btn.textContent = this.labels.nothing;
        });
      } else {
        // Some checked.
        [].forEach.call(this.buttons.acceptSelection, btn => {
          btn.textContent = this.labels.selected;
        });
      }
    },

    _checkCategorySelection(e) {
      setTimeout(() => {
        if (e.target.checked) {
          // Category checked.
          [].forEach.call(this.buttons.acceptSelection, btn => {
            btn.textContent = this.labels.selected;
          });
        }
        else if (this.isNoneChecked()) {
          // Category not checked.
          [].forEach.call(this.buttons.acceptSelection, btn => {
            btn.textContent = this.labels.nothing;
          });
        }
      }, 100);
    }
  };

})(Drupal);
