(function (Drupal) {
  Drupal.behaviors.legalwebCloudEnhancements = {
    attach: function attach(context, settings) {
      var _this = this;

      this.overlay = context.querySelector('.sp-dsgvo-popup-overlay');

      if (!this.overlay) {
        return;
      }

      this.initValues();

      if (settings.legalwebCloudEnhancements.adjustButtonLabels) {
        this.adjustButtonLabels();

        this._checkSelection();

        [].forEach.call(this.checkboxes, function (checkbox) {
          checkbox.addEventListener('change', _this._checkSelection.bind(_this));
        });
        [].forEach.call(this.categories, function (category) {
          category.addEventListener('change', _this._checkCategorySelection.bind(_this));
        });
      }

      if (settings.legalwebCloudEnhancements.removeCloseButton) {
        this.removeCloseButton();
      }

      if (settings.legalwebCloudEnhancements.disableOutsideClick) {
        this.disableOutsideClickBehavior();
      }
    },
    initValues: function initValues() {
      this.popup = this.overlay.querySelector('.sp-dsgvo-privacy-popup');
      this.buttons = {};
      this.buttons.all = this.popup.querySelectorAll('.sp-dsgvo-popup-button');
      this.buttons.acceptSelection = this.popup.querySelectorAll('.sp-dsgvo-privacy-btn-accept-selection');
      this.buttons.acceptNothing = this.popup.querySelectorAll('.sp-dsgvo-privacy-btn-accept-nothing');
      this.checkboxes = this.popup.querySelectorAll('.switch-input:not(.switch-input-category)');
      this.categories = this.popup.querySelectorAll('.switch-input-category');
    },
    disableOutsideClickBehavior: function disableOutsideClickBehavior() {
      window.addEventListener('click', this._clickOutHandler, {
        capture: true
      });
      window.addEventListener('touchstart', this._clickOutHandler, {
        capture: true
      });
    },
    removeCloseButton: function removeCloseButton() {
      var closeBtn = this.popup.querySelector('.sp-dsgvo-popup-close');

      if (null !== closeBtn) {
        closeBtn.remove();
      }
    },
    adjustButtonLabels: function adjustButtonLabels() {
      [].forEach.call(this.buttons.all, function (btn) {
        btn.style.minWidth = '40%';
        btn.style.textAlign = 'center';
      });
      this.labels = {
        selected: this.buttons.acceptSelection[0].textContent,
        nothing: this.buttons.acceptNothing[0].textContent
      };
      [].forEach.call(this.buttons.acceptNothing, function (btn) {
        btn.remove();
      });
    },
    isNoneChecked: function isNoneChecked() {
      return this.popup.querySelectorAll('input.switch-input:not(.switch-input-category):checked').length === 0;
    },
    _clickOutHandler: function _clickOutHandler(e) {
      if (e.target.classList.contains('sp-dsgvo-popup-overlay')) {
        e.stopPropagation();
        return false;
      }
    },
    _checkSelection: function _checkSelection() {
      var _this2 = this;

      if (this.isNoneChecked()) {
        [].forEach.call(this.buttons.acceptSelection, function (btn) {
          btn.textContent = _this2.labels.nothing;
        });
      } else {
        [].forEach.call(this.buttons.acceptSelection, function (btn) {
          btn.textContent = _this2.labels.selected;
        });
      }
    },
    _checkCategorySelection: function _checkCategorySelection(e) {
      var _this3 = this;

      setTimeout(function () {
        if (e.target.checked) {
          [].forEach.call(_this3.buttons.acceptSelection, function (btn) {
            btn.textContent = _this3.labels.selected;
          });
        } else if (_this3.isNoneChecked()) {
          [].forEach.call(_this3.buttons.acceptSelection, function (btn) {
            btn.textContent = _this3.labels.nothing;
          });
        }
      }, 100);
    }
  };
})(Drupal);